@@ -1,15 +1,15 @@
 from .item import Item
 from .artist_list_item import ArtistListItem
 
-class ArtistsInitial(Item):
+class ArtistsInitial:
 
     def __init__(self, data : dict):
-        super().__init__(data)
+        self.__item : Item = Item(data)
 
     def getName(self) -> str | None:
-        return self.getByName("name")
+        return self.__item.getByName("name")
 
     def getArtistListItems(self) -> list[ArtistListItem]:
         return list(map(
             lambda x : ArtistListItem(x), 
-            self.getList(["artist"])))
\ No newline at end of file
+            self.__item.getList(["artist"])))
\ No newline at end of file
