@@ -1,15 +1,10 @@
 from .item import Item
-from .response import Response
 from .genre import Genre
 
 class Genres:
 
     def __init__(self, data : dict):
         self.__item : Item = Item(data)
-        self.__response : Response = Response(data)
-
-    def getResponse(self) -> Response:
-        return self.__response
 
     def getGenres(self) -> list[Genre]:
         return list(map(
