@@ -6,7 +6,7 @@ from typing import Generic, TypeVar
 T = TypeVar("T")
 
 class Response(Generic[T]):
-    
+
     def __init__(self, data : dict, t : T):
         self.__item : Item = Item(data)
         self.__t = t
@@ -18,4 +18,7 @@ class Response(Generic[T]):
         return self.__item.getByName("status")
 
     def getVersion(self) -> str | None:
-        return self.__item.getByName("version")
\ No newline at end of file
+        return self.__item.getByName("version")
+    
+    def isOk(self) -> bool:
+        return self.getStatus() == "ok"
\ No newline at end of file
